@@ -9,6 +9,7 @@ from json import dumps, loads
 import html
 import math
 from urllib.parse import unquote
+from babel.numbers import format_decimal
 
 
 class HtmlExtension(Extension):
@@ -681,17 +682,19 @@ class CasinosExtension(Extension):
             #     current_app.redis.hset('aggs', id, _c)
             #     logger.info('Cache aggs {0}: {1}'.format(id, len(_c)))
         else:
-            pages, found = Page.provider_by_context(
-                is_searchable=True,
-                is_redirect=False,
-                country=current_user.country_full,
-                tags='casino',
-                provider_tags=tags,
-                locale_available=g.language,
-                _locale=g.language,
-                _source=True, 
-                _count=count,
-            )
+            kwargs = {
+                'is_searchable': True,
+                'is_redirect': False,
+                'country': current_user.country_full,
+                'tags': 'casino',
+                'provider_tags': tags,
+                '_source': True, 
+                '_count': count,
+            }
+            if len(current_app.config['AVAILABLE_LOCALE']) > 1:
+                kwargs['locale_available'] = g.language
+
+            pages, found = Page.provider_by_context(**kwargs)
 
         t = current_app.jinja_env.get_template('_ext-{0}.html'.format(template))
         s = t.render(
@@ -1297,3 +1300,20 @@ class ComplaintAddExtension(Extension):
             parser.stream.skip_if('comma')
 
         return CallBlock(self.call_method("_render", args=[List(args)]), [], [], []).set_lineno(lineno)          
+
+
+class CryptoRatesExtension(Extension):
+    tags = set(['crypto_rates'])
+
+    def __init__(self, environment):
+        super(CryptoRatesExtension, self).__init__(environment)
+
+    def _render(self, caller):
+        t = current_app.jinja_env.get_template('_ext-crypto_rates.html')
+        crypto_rates = {k.decode(): format_decimal(v.decode(), locale=g.language) for k, v in current_app.redis.hgetall('crypto_rates').items()}
+        s = t.render(crypto_rates=crypto_rates)
+        return s
+
+    def parse(self, parser):
+        lineno = next(parser.stream).lineno
+        return CallBlock(self.call_method("_render", []), [], [], '').set_lineno(lineno)
