@@ -141,7 +141,7 @@ class ElasticEntity(BaseEntity):
         return "{0}.v1".format(cls.__name__.lower())
 
     @classmethod
-    def get(cls, _id=None, _count=10, _offset=0, _sort=[], _process=True, _source=None, _exclude=[], _all=False, _random=False, _range=None, **kwargs):
+    def get(cls, _id=None, _count=10, _offset=0, _sort=[], _process=True, _source=None, _exclude=[], _exclude_params={}, _all=False, _random=False, _range=None, **kwargs):
         if _id:
             resp = current_app.es.get(index=cls._table(), id=_id, ignore=[400, 404])
             logger.debug(u'GET: {0}'.format(resp))
@@ -164,10 +164,15 @@ class ElasticEntity(BaseEntity):
                 "must": must
             }
 
+            must_not = []
+            if _exclude_params:
+                must_not.append({"terms" if isinstance(v, list) else "term": {pre_field(k, v): v} for k, v in _exclude_params.items()})
             if _exclude:
-                qbool['must_not'] = [
-                    {'ids': {'values': _exclude}}
-                ]
+                must_not.append({'ids': {'values': _exclude}})
+            if must_not:
+                qbool['must_not'] = must_not
+
+            logger.info(qbool)
 
             if _random:
                 def get_func():
@@ -336,6 +341,7 @@ class Page(ElasticEntity):
         'category': str,
         'locale': str,
         'locale_available': list, # for lang version
+        'hreflang': str,
         'source_chain': list,
         'api_source': str,
         'alias': str,
@@ -363,6 +369,7 @@ class Page(ElasticEntity):
         'custom_text': str,
         'has_toc': bool,
         'attachs': list,
+        'screen_list': list,
         'software': list,
         'rating': int,
         'boost': float,
@@ -746,6 +753,7 @@ class Page(ElasticEntity):
             'collection_sort': ['Func_1', 'Func_2', 'Rate', 'Rank', 'Views', 'Activity', 'Alexa', 'Adding', 'AZ', 'Launched', 'RTP', 'MaxWin', 'Jackpot', 'Min.Deposit'],
             'collection_sort_direction': ['Desc', 'Asc'],
             'collection_paging': ['FirstPage', 'Paging'],
+            'hreflangs': current_app.config['AVAILABLE_LOCALE'],
         }
         
         return opts
